import { useSelect } from '@wordpress/data';
import { useBlockProps } from '@wordpress/block-editor';

export default function Block(props) {
	const blockProps = useBlockProps();
	const { showExcerpt, showThumbnail, thumbnailSize, orderBy, htmlTag } =
		props;

	let infoCurrentPostType = '';

	const childrenPosts = useSelect((select) => {
		const allPosts = [];
		//Get the Id of the current Post
		const currentPostId = select('core/editor').getCurrentPostId();
		//Get post type of the current Post
		const currentPostType = select('core/editor').getCurrentPostType();
		//console.log('currentPostType',currentPostType)

		const allPostType = select('core').getPostTypes();

		if (allPostType) {
			infoCurrentPostType = allPostType.filter(
				(element) => element.slug === currentPostType
			);
		}

		//Get all pages from a parent page
		const children = select('core').getEntityRecords(
			'postType',
			currentPostType,
			{
				order_by: orderBy,
				order: 'asc',
				parent: currentPostId,
				per_page: -1,
			}
		);

		//Create an array of objects with all the information that we need
		if (children) {
			children.forEach(function (element) {
				//Get a media
				const media = select('core').getMedia(element.featured_media);
				const object = {
					title: element.title.rendered,
					excerpt: element.excerpt.rendered,
					link: element.link,
				};
				if (media && thumbnailSize) {
					object.image = media.media_details.sizes[thumbnailSize]
						? media.media_details.sizes[thumbnailSize].source_url
						: media.media_details.sizes.full.source_url;
					object.imageAlt = media.alt_text;
				}
				allPosts.push(object);
			});

			return allPosts;
		}
	});

	const HtmlTag = htmlTag;

	return (
		<div {...blockProps}>
			<div>
				{childrenPosts &&
				childrenPosts.length > 0 &&
				infoCurrentPostType[0] &&
				infoCurrentPostType[0].hierarchical === true ? (
					<ul>
						{childrenPosts &&
							childrenPosts.map((element) => (
								<li key={element.title}>
									{element.image && showThumbnail && (
										<figure>
											<img
												src={element.image}
												alt={element.imageAlt}
											/>
										</figure>
									)}
									<HtmlTag>{element.title}</HtmlTag>
									{element.excerpt && showExcerpt && (
										<div
											dangerouslySetInnerHTML={{
												__html: element.excerpt,
											}}
										></div>
									)}
								</li>
							))}
					</ul>
				) : (
					<p className={'no-content'}>
						Affichage de la liste des pages filles
					</p>
				)}
			</div>
			{infoCurrentPostType &&
				infoCurrentPostType.length > 0 &&
				infoCurrentPostType[0].hierarchical === false && (
					<p> Type de posts non hiérarchique </p>
				)}
		</div>
	);
}
