import {
	Panel,
	PanelBody,
	ToggleControl,
	SelectControl,
} from '@wordpress/components';
import { __ } from '@wordpress/i18n';
import {
	InspectorControls,
	store as blockEditorStore,
} from '@wordpress/block-editor';
import { useSelect } from '@wordpress/data';

export default function Inspector(props) {
	const {
		showExcerpt,
		showThumbnail,
		setAttributes,
		thumbnailSize,
		htmlTag,
		idTagName,
		idCategorieName,
		categoriesList,
		tagsList,
	} = props;

	const imageSizes = useSelect((select) => {
		return select(blockEditorStore)
			.getSettings()
			.imageSizes.map((image) => {
				return {
					value: image.slug,
					label: image.name,
				};
			});
	});

	//Création d'un tableau avec les tags et leur ID
	const tagArrayId = useSelect((select) => {
		const allTags = select('core').getEntityRecords(
			'taxonomy',
			'post_tag',
			{
				per_page: -1,
			}
		);
		const arrayNameId = [];

		if (allTags) {
			allTags.forEach(function (element) {
				const array = [element.id, element.name, element.link];
				arrayNameId.push(array);
			});
		}
		return arrayNameId;
	});

	let i = -1;

	while (++i < tagArrayId.length) {
		tagsList[i] = tagArrayId[i];
	}

	//Fonction qui permet de mettre en majuscule la 1ère lettre de l'expression injecté
	function capitalizeFirstLetter(string) {
		return string.charAt(0).toUpperCase() + string.slice(1);
	}

	//Initialisation d'un tableau d'objets des options de notre SelectControl pour le choix de notre Tag
	const options = [
		{
			value: undefined,
			label: 'Aucun',
		},
	];

	//On injecte à l'aide d'une boucle les données du tableau dans les options de notre SelectControl correspondant au choix de nos tags
	if (tagArrayId) {
		tagArrayId.forEach(function (value) {
			const object = {
				value: value[0],
				label: capitalizeFirstLetter(value[1]),
			};
			options.push(object);
		});
	}

	//Création d'un tableau avec les categories et leur ID
	const categorieArrayId = useSelect((select) => {
		const allCategories = select('core').getEntityRecords(
			'taxonomy',
			'tribe_events_cat',
			{
				per_page: -1,
			}
		);
		const arrayNameId = [];

		if (allCategories) {
			allCategories.forEach(function (element) {
				const array = [element.id, element.name, element.link];
				arrayNameId.push(array);
			});
		}
		return arrayNameId;
	});

	let z = -1;

	while (++z < categorieArrayId.length) {
		categoriesList[z] = categorieArrayId[z];
	}

	//Initialisation d'un tableau d'objets des options de notre SelectControl pour le choix de notre categorie
	const optionsCategories = [
		{
			value: undefined,
			label: 'Aucun',
		},
	];

	//On injecte à l'aide d'une boucle les données du tableau dans les options de notre SelectControl correspondant au choix de nos categories
	if (categorieArrayId) {
		categorieArrayId.forEach(function (value) {
			const object = {
				value: value[0],
				label: capitalizeFirstLetter(value[1]),
			};
			optionsCategories.push(object);
		});
	}

	return (
		<InspectorControls>
			<Panel>
				<PanelBody>
					<ToggleControl
						label={__("Afficher l'extrait", 'bsw-blocks')}
						checked={showExcerpt}
						onChange={(showExcerpt) =>
							setAttributes({ showExcerpt })
						}
					/>
					<ToggleControl
						label={__("Afficher l'image", 'bsw-blocks')}
						checked={showThumbnail}
						onChange={(showThumbnail) =>
							setAttributes({ showThumbnail })
						}
					/>
					{showThumbnail && (
						<SelectControl
							value={thumbnailSize}
							options={imageSizes}
							label={__("Taille de l'image", 'bsw-blocks')}
							onChange={(newThumbnailSize) =>
								setAttributes({
									thumbnailSize: newThumbnailSize,
								})
							}
						/>
					)}

					<SelectControl
						value={htmlTag}
						options={[
							{ value: 'p', label: __('p') },
							{ value: 'h1', label: __('h1') },
							{ value: 'h2', label: __('h2') },
							{ value: 'h3', label: __('h3') },
							{ value: 'h4', label: __('h4') },
							{ value: 'h5', label: __('h5') },
							{ value: 'h6', label: __('h6') },
						]}
						label={__(
							'Balise Html pour le titre des articles',
							'bsw-blocks'
						)}
						onChange={(htmlTag) => setAttributes({ htmlTag })}
					/>
				</PanelBody>
				<PanelBody title={__('Filtre', 'bsw-blocks')} initialOpen>
					<SelectControl
						value={idTagName}
						options={options}
						label={__('Tags', 'scrollable-gallery')}
						onChange={(newIdTagName) =>
							setAttributes({ idTagName: newIdTagName })
						}
					/>
					<SelectControl
						value={idCategorieName}
						options={optionsCategories}
						label={__('Categories', 'scrollable-gallery')}
						onChange={(newIdCategorieName) =>
							setAttributes({
								idCategorieName: newIdCategorieName,
							})
						}
					/>
				</PanelBody>
			</Panel>
		</InspectorControls>
	);
}
