import { useSelect } from '@wordpress/data';
import { useBlockProps } from '@wordpress/block-editor';

export default function Block(props) {
	const { thumbnailSize, postsIds, showExcerpt, showThumbnail } = props;

	const blockProps = useBlockProps();

	const postsSelected = useSelect((select) => {
		const array = [];

		const excludedPostTypes = ['attachment'];
		//Filtrer pour récupérer les types de post qui nous intéressent
		const postTypes = select('core')
			.getPostTypes({ per_page: -1 })
			?.filter(
				({ viewable, slug }) =>
					viewable && !excludedPostTypes.includes(slug)
			);

		if (postTypes && postTypes.length > 0) {
			postsIds.forEach((postId) => {
				postTypes.forEach((postType) => {
					const post = select('core').getEntityRecord(
						'postType',
						postType.slug,
						postId
					);

					if (post) {
						const media = select('core').getMedia(
							post.featured_media
						);
						const object = {
							title: post.title.rendered,
							excerpt: post.excerpt ? post.excerpt.rendered : '',
							link: post.link,
						};

						if (media && thumbnailSize) {
							object.image = media.media_details.sizes[
								thumbnailSize
							]
								? media.media_details.sizes[thumbnailSize]
										.source_url
								: media.media_details.sizes.full.source_url;
							object.imageAlt = media.alt_text;
						}
						array.push(object);
					}
				});
			});
		}
		return array;
	});

	return (
		<ul {...blockProps}>
			{postsSelected.map((post) => (
				<li key={post.title}>
					{post.image && showThumbnail && (
						<figure>
							<img src={post.image} alt={post.imageAlt} />
						</figure>
					)}
					<h2>{post.title}</h2>
					{showExcerpt && (
						<p
							dangerouslySetInnerHTML={{
								__html: post.excerpt,
							}}
						></p>
					)}
				</li>
			))}
		</ul>
	);
}
