import { MultiSelectControl } from '@codeamp/block-components';
import {
	Panel,
	PanelBody,
	ToggleControl,
	SelectControl,
} from '@wordpress/components';
import {
	InspectorControls,
	store as blockEditorStore,
} from '@wordpress/block-editor';
import { __ } from '@wordpress/i18n';
import { useSelect } from '@wordpress/data';

export default function Inspector(props) {
	const {
		postsIds,
		setAttributes,
		showExcerpt,
		showThumbnail,
		thumbnailSize,
	} = props;

	const imageSizes = useSelect((select) => {
		const array = select(blockEditorStore)
			.getSettings()
			.imageSizes.map((image) => {
				return {
					value: image.slug,
					label: image.name,
				};
			});
		return array;
	});

	//Création d'un tableau avec tous les posts/articles/custom posts
	const allPosts = useSelect((select) => {
		const excludedPostTypes = ['attachment'];
		//Filtrer pour récupérer les types de post qui nous intéressent
		const postTypes = select('core')
			.getPostTypes({ per_page: -1 })
			?.filter(
				({ viewable, slug }) =>
					viewable && !excludedPostTypes.includes(slug)
			);
		let postsArray = [];
		if (postTypes && postTypes.length > 0) {
			postTypes.forEach((postType) => {
				postsArray.push(
					select('core').getEntityRecords('postType', postType.slug)
				);
			});
			postsArray = postsArray.flat();
		}

		return postsArray;
	});

	//Création d'un tableau pour tous les noms des posts/articles/custom post qui nous servent pour le panneau de controle
	const options = [];

	if (allPosts && allPosts.length > 1) {
		allPosts.forEach((post) => {
			if (post !== null) {
				const object = {
					label: post.title.rendered,
					value: post.id,
				};
				options.push(object);
			}
		});
	}

	return (
		<InspectorControls>
			<Panel>
				<PanelBody>
					<MultiSelectControl
						value={postsIds}
						options={options}
						onChange={(postsIds) => {
							setAttributes({ postsIds });
						}}
					/>

					<ToggleControl
						label={__("Afficher l'image", 'bsw-blocks')}
						checked={showThumbnail}
						onChange={(showThumbnail) =>
							setAttributes({ showThumbnail })
						}
					/>
					{showThumbnail && (
						<SelectControl
							value={thumbnailSize}
							options={imageSizes}
							label={__("Taille de l'image", 'bsw-blocks')}
							onChange={(newThumbnailSize) =>
								setAttributes({
									thumbnailSize: newThumbnailSize,
								})
							}
						/>
					)}

					<ToggleControl
						label={__('Afficher la description', 'bsw-blocks')}
						checked={showExcerpt}
						onChange={(showExcerpt) =>
							setAttributes({ showExcerpt })
						}
					/>
				</PanelBody>
			</Panel>
		</InspectorControls>
	);
}
