/**
 * Lets webpack process CSS, SASS or SCSS files referenced in JavaScript files.
 * Those files can contain any CSS code that gets applied to the editor.
 *
 * @see https://www.npmjs.com/package/@wordpress/scripts#using-css
 */
import './editor.scss';
import { Fragment } from '@wordpress/element';
import Inspector from './inspector';
import Block from './block';

/**
 * The edit function describes the structure of your block in the context of the
 * editor. This represents what the editor will render when the block is used.
 *
 * @param {Object} props
 * @see https://developer.wordpress.org/block-editor/reference-guides/block-api/block-edit-save/#edit
 *
 * @return {WPElement} Element to render.
 */
export default function Edit(props) {
	const { attributes, setAttributes } = props;

	const {
		showExcerpt,
		showThumbnail,
		thumbnailSize,
		orderBy,
		showCurrentPage,
		htmlTag,
	} = attributes;

	return (
		<Fragment>
			<Inspector
				{...{
					setAttributes,
					showExcerpt,
					showThumbnail,
					thumbnailSize,
					orderBy,
					showCurrentPage,
					htmlTag,
				}}
			/>
			<Block
				{...{
					setAttributes,
					showExcerpt,
					showThumbnail,
					thumbnailSize,
					orderBy,
					showCurrentPage,
					htmlTag,
				}}
			/>
		</Fragment>
	);
}
